==> gpick_0.2.5.orig.tar.gz: gpick_0.2.5/source/transformation/Factory.h <==
/*
 * Copyright (c) 2009-2012, Albertas Vyšniauskas
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 *     * Neither the name of the software author nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef TRANSFORMATION_FACTORY_H_
#define TRANSFORMATION_FACTORY_H_

#include "Transformation.h"
#include <boost/shared_ptr.hpp>
#include <vector>

/** \file source/transformation/Factory.h
 * \brief Class for transformation object creation.
 */

namespace transformation {

/** \class Factory
 * \brief Transformation object creation management class.
 */
class Factory{
	public:
    typedef struct TypeInfo{
			const char *name;
			const char *human_name;
			TypeInfo(const char *name, const char *human_name);
		}TypeInfo;

		/**
		 * Create new transformation object.
		 * @param[in] type Name of transformation object type.
		 * @return New transformation object.
		 */
		static boost::shared_ptr<Transformation> create(const char *type);

		/**
		 * Get all transformation object types.
		 * @return Vector of transformation object type information structures.
		 */
		static std::vector<TypeInfo> getAllTypes();
};

}

#endif /* TRANSFORMATION_FACTORY_H_ */

==> gpick-0.3.tar.gz: gpick-0.3/source/transformation/Factory.h <==
/*
 * Copyright (c) 2009-2021, Albertas Vyšniauskas
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 *     * Neither the name of the software author nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef GPICK_TRANSFORMATION_FACTORY_H_
#define GPICK_TRANSFORMATION_FACTORY_H_
#include <vector>
#include <string>
#include <memory>
/** \file source/transformation/Factory.h
 * \brief Struct for transformation object creation.
 */
namespace transformation {
struct Transformation;
/** \struct Factory
 * \brief Transformation object creation management struct.
 */
struct Factory {
	struct TypeInfo {
		const char *id;
		const char *name;
		TypeInfo(const char *id, const char *name);
	};
	/**
		 * Create new transformation object.
		 * @param[in] type Name of transformation object type.
		 * @return New transformation object.
		 */
	static std::unique_ptr<Transformation> create(const std::string &type);
	/**
		 * Get all transformation object types.
		 * @return Vector of transformation object type information structures.
		 */
	static std::vector<TypeInfo> getAllTypes();
};
}
#endif /* GPICK_TRANSFORMATION_FACTORY_H_ */
